@@ -1,6 +1,7 @@
 //! # Orthogonal chebyshev space
 use crate::traits::Basics;
 use crate::traits::Differentiate;
+use crate::traits::DifferentiatePar;
 use crate::traits::FromOrtho;
 use crate::traits::FromOrthoPar;
 use crate::traits::LaplacianInverse;
@@ -449,7 +450,6 @@ macro_rules! impl_differentiate_chebyshev {
                 S: ndarray::Data<Elem = $a>,
                 D: Dimension,
             {
-                // Copy input
                 let mut output = data.to_owned();
                 self.differentiate_inplace(&mut output, n_times, axis);
                 output
@@ -471,6 +471,39 @@ macro_rules! impl_differentiate_chebyshev {
                 });
             }
         }
+
+        impl<A: FloatNum> DifferentiatePar<$a> for Chebyshev<A> {
+            fn differentiate_par<S, D>(
+                &self,
+                data: &ArrayBase<S, D>,
+                n_times: usize,
+                axis: usize,
+            ) -> Array<$a, D>
+            where
+                S: ndarray::Data<Elem = $a>,
+                D: Dimension,
+            {
+                let mut output = data.to_owned();
+                self.differentiate_inplace_par(&mut output, n_times, axis);
+                output
+            }
+
+            fn differentiate_inplace_par<S, D>(
+                &self,
+                data: &mut ArrayBase<S, D>,
+                n_times: usize,
+                axis: usize,
+            ) where
+                S: ndarray::Data<Elem = $a> + ndarray::DataMut,
+                D: Dimension,
+            {
+                use crate::utils::check_array_axis;
+                check_array_axis(data, self.m, axis, Some("chebyshev differentiate"));
+                ndarray::Zip::from(data.lanes_mut(Axis(axis))).par_for_each(|mut lane| {
+                    self.differentiate_lane(&mut lane, n_times);
+                });
+            }
+        }
     };
 }
 
