@@ -10,6 +10,7 @@
 #![allow(clippy::module_name_repetitions)]
 use crate::traits::Basics;
 use crate::traits::Differentiate;
+use crate::traits::DifferentiatePar;
 use crate::traits::FromOrtho;
 use crate::traits::FromOrthoPar;
 use crate::traits::LaplacianInverse;
@@ -167,6 +168,40 @@ impl<A: FloatNum> Differentiate<Complex<A>> for FourierC2c<A> {
     }
 }
 
+/// Perform differentiation in spectral space
+impl<A: FloatNum> DifferentiatePar<Complex<A>> for FourierC2c<A> {
+    fn differentiate_par<S, D>(
+        &self,
+        data: &ArrayBase<S, D>,
+        n_times: usize,
+        axis: usize,
+    ) -> Array<Complex<A>, D>
+    where
+        S: ndarray::Data<Elem = Complex<A>>,
+        D: Dimension,
+    {
+        let mut output = data.to_owned();
+        self.differentiate_inplace_par(&mut output, n_times, axis);
+        output
+    }
+
+    fn differentiate_inplace_par<S, D>(
+        &self,
+        data: &mut ArrayBase<S, D>,
+        n_times: usize,
+        axis: usize,
+    ) where
+        S: ndarray::Data<Elem = Complex<A>> + ndarray::DataMut,
+        D: Dimension,
+    {
+        use crate::utils::check_array_axis;
+        check_array_axis(data, self.m, axis, Some("fourier differentiate"));
+        ndarray::Zip::from(data.lanes_mut(Axis(axis))).par_for_each(|mut lane| {
+            self.differentiate_lane(&mut lane, n_times);
+        });
+    }
+}
+
 impl<A: FloatNum> Transform for FourierC2c<A> {
     type Physical = Complex<A>;
     type Spectral = Complex<A>;
@@ -329,7 +364,7 @@ impl<A: FloatNum> TransformPar for FourierC2c<A> {
     {
         use crate::utils::array_resized_axis;
         let mut output = array_resized_axis(input, self.m, axis);
-        self.forward_inplace(input, &mut output, axis);
+        self.forward_inplace_par(input, &mut output, axis);
         output
     }
 
@@ -386,7 +421,7 @@ impl<A: FloatNum> TransformPar for FourierC2c<A> {
     {
         use crate::utils::array_resized_axis;
         let mut output = array_resized_axis(input, self.n, axis);
-        self.backward_inplace(input, &mut output, axis);
+        self.backward_inplace_par(input, &mut output, axis);
         output
     }
 
